@@ -53,11 +53,11 @@ struct b2WeldJointDef : public b2JointDef
 class b2WeldJoint : public b2Joint
 {
 public:
-	b2Vec2 GetAnchorA() const Q_DECL_OVERRIDE;
-	b2Vec2 GetAnchorB() const Q_DECL_OVERRIDE;
+	b2Vec2 GetAnchorA() const override;
+	b2Vec2 GetAnchorB() const override;
 
-	b2Vec2 GetReactionForce(qreal inv_dt) const Q_DECL_OVERRIDE;
-	qreal GetReactionTorque(qreal inv_dt) const Q_DECL_OVERRIDE;
+	b2Vec2 GetReactionForce(qreal inv_dt) const override;
+	qreal GetReactionTorque(qreal inv_dt) const override;
 
 protected:
 
@@ -65,10 +65,10 @@ protected:
 
 	b2WeldJoint(const b2WeldJointDef* def);
 
-	void InitVelocityConstraints(const b2TimeStep& step) Q_DECL_OVERRIDE;
-	void SolveVelocityConstraints(const b2TimeStep& step) Q_DECL_OVERRIDE;
+	void InitVelocityConstraints(const b2TimeStep& step) override;
+	void SolveVelocityConstraints(const b2TimeStep& step) override;
 
-	bool SolvePositionConstraints(qreal baumgarte) Q_DECL_OVERRIDE;
+	bool SolvePositionConstraints(qreal baumgarte) override;
 
 	b2Vec2 m_localAnchorA;
 	b2Vec2 m_localAnchorB;
