@@ -35,18 +35,23 @@
 
 using namespace std;
 
-static const char description[] =
-I18N_NOOP("KDE Minigolf Game");
-
 int main(int argc, char **argv)
 {
     // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kolf");
 
-	KAboutData aboutData( QStringLiteral("kolf"), i18n("Kolf"), QStringLiteral(KOLF_VERSION_STRING), i18n(description), KAboutLicense::GPL, i18n("(c) 2002-2010, Kolf developers"),  QStringLiteral("https://games.kde.org/kolf"));
+    KAboutData aboutData( QStringLiteral("kolf"),
+			  i18n("Kolf"),
+			  QStringLiteral(KOLF_VERSION_STRING),
+			  i18n("KDE Minigolf Game"),
+			  KAboutLicense::GPL,
+			  i18n("(c) 2002-2010, Kolf developers"),
+			  QStringLiteral("https://apps.kde.org/kolf"));
 
 	aboutData.addAuthor(i18n("Stefan Majewsky"), i18n("Current maintainer"), QStringLiteral("majewsky@gmx.net"));
 	aboutData.addAuthor(i18n("Jason Katz-Brown"), i18n("Former main author"), QStringLiteral("jasonkb@mit.edu"));
